@@ -3,6 +3,7 @@ from __future__ import annotations
 
 import datetime as dt
 import json
+import logging
 import os
 from contextlib import contextmanager
 from dataclasses import asdict, is_dataclass
@@ -12,7 +13,6 @@ from typing import Any, Iterator, Optional, Union
 from urllib.parse import urlparse
 
 from dbt.contracts.results import RunExecutionResult, agate
-from dbt.logger import log_manager
 
 from airflow import AirflowException
 from airflow.models.baseoperator import BaseOperator
@@ -48,6 +48,7 @@ class DbtBaseOperator(BaseOperator):
         "profile",
         "target",
         "state",
+        "vars",
     ]
 
     @apply_defaults
@@ -89,6 +90,7 @@ class DbtBaseOperator(BaseOperator):
         s3_conn_id: str = "aws_default",
         do_xcom_push_artifacts: Optional[list[str]] = None,
         push_dbt_project: bool = False,
+        replace_on_push: bool = True,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -134,6 +136,8 @@ class DbtBaseOperator(BaseOperator):
         self.s3_conn_id = s3_conn_id
         self.do_xcom_push_artifacts = do_xcom_push_artifacts
         self.push_dbt_project = push_dbt_project
+        self.replace_on_push = replace_on_push
+
         self._s3_hook = None
         self._dbt_hook = None
 
@@ -252,7 +256,9 @@ class DbtBaseOperator(BaseOperator):
                 and urlparse(str(store_project_dir)).scheme == "s3"
             ):
                 self.log.info("Pushing dbt project back to S3: %s", store_project_dir)
-                self.s3_hook.push_dbt_project(store_project_dir, tmp_dir)
+                self.s3_hook.push_dbt_project(
+                    store_project_dir, tmp_dir, self.replace_on_push
+                )
 
         self.profiles_dir = store_profiles_dir
         self.project_dir = store_project_dir
@@ -297,18 +303,17 @@ class DbtBaseOperator(BaseOperator):
     def override_dbt_logging(self, dbt_directory: str = None):
         """Override dbt's logger.
 
-        We override the output stream of the dbt logger to use Airflow's StreamLogWriter
-        so that we can ensure dbt logs properly to the Airflow task's log output.
+        Starting with dbt v1, dbt initializes two loggers: default_file and
+        default_stdout. We override default_stdout's handlers with Airflow logger's
+        handlers.
         """
-        from airflow.utils.log.logging_mixin import StreamLogWriter
+        file_logger = logging.getLogger("default_file")
+        file_logger.handlers = []
 
-        with log_manager.applicationbound():
-            log_manager.reset_handlers()
-            log_manager.set_path(dbt_directory)
-            log_manager.set_output_stream(
-                StreamLogWriter(self.log, self.log.getEffectiveLevel())
-            )
-            yield
+        stdout_logger = logging.getLogger("default_stdout")
+        stdout_logger.handlers = self.log.handlers
+
+        yield
 
     def serializable_result(
         self, result: Optional[RunExecutionResult]
